.. image:: https://travis-ci.org/ambitioninc/django-db-mutex.png
   :target: https://travis-ci.org/ambitioninc/django-db-mutex

django-db-mutex
===============
Provides the ability to acquire a mutex lock from the database in Django.


Installation
------------
To install the latest release, type::

    pip install django-db-mutex

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-db-mutex.git

Documentation
-------------

Full documentation is available at http://django-db-mutex.readthedocs.org

License
-------
MIT License (see LICENSE)
